﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.ComponentModel;

namespace DataGridApplication
{
    public class CommunityViewModel : INotifyPropertyChanged
    {
        public CommunityViewModel(List<PersonViewModel> members)
        {
            this.Members = members;

            foreach (PersonViewModel member in members)
                member.PropertyChanged += delegate
                {
                    this.OnPropertyChanged("AllMembersAreChecked");
                };
        }

        public List<PersonViewModel> Members { get; private set; }

        public bool? AllMembersAreChecked
        {
            get
            {
                bool? value = null;
                for (int i = 0; i < this.Members.Count; ++i)
                {
                    if (i == 0)
                    {
                        value = this.Members[0].IsChecked;
                    }
                    else if (value != this.Members[i].IsChecked)
                    {
                        value = null;
                        break;
                    }
                }

                return value;
            }
            set
            {
                if (value == null)
                    return;

                foreach (PersonViewModel member in this.Members)
                    member.IsChecked = value.Value;
            }
        }

        #region INotifyPropertyChanged Members

        public event PropertyChangedEventHandler PropertyChanged;

        void OnPropertyChanged(string prop)
        {
            if (this.PropertyChanged != null)
                this.PropertyChanged(this, new PropertyChangedEventArgs(prop));
        }

        #endregion
    }
}
